Trying to log data from UM6 sensor with GPS receiver LS20031. I have two problems: - I can't log to file at a fast rate (<0.5s) without data values freezing to a fixed value. Print to pc screen it works fine. Ideally I would do this with an interrupt (e.g. ticker) so that the time of each reading is a fixed interval - I removed this as I thought this was causing the problem. - I want to record GPS lat and long. I have setup the GPS ground speed so I know the sensor are communicating. So I possibly havent set the config file to correctly interpet these two signals.

Dependencies:   MODSERIAL mbed

Fork of UM6_IMU_AHRS_2012 by lhiggs CSUM

Revision:
1:20201cda90d0
Parent:
0:03c649c76388
Child:
2:db3bbd57b075
--- a/main.cpp	Fri Sep 28 00:40:29 2012 +0000
+++ b/main.cpp	Wed May 01 19:06:43 2013 +0000
@@ -4,6 +4,8 @@
 #include "UM6_usart.h"     // UM6 USART HEADER
 #include "UM6_config.h"    // UM6 CONFIG HEADER
 
+LocalFileSystem local("local");               // Create the local filesystem under the name "local"
+
 /////////////////////////////////////////////////////////////////////////////////////////////
 // SETUP (ASSIGN) SERIAL COMMUNICATION PINS ON MBED
 /////////////////////////////////////////////////////////////////////////////////////////////
@@ -14,7 +16,12 @@
 ////////////////////////////////////////////////////////////////////////////////////////////////
 DigitalOut pc_activity(LED1);    // LED1 = PC SERIAL
 DigitalOut uart_activity(LED2);  // LED2 = UM6 SERIAL
+DigitalOut logLED(LED3);  // LED3 = logging active
 
+DigitalIn enable(p5);    // enable signal for logging data to file
+
+Timer t; // sets up timer 't'
+Ticker tick; // sets up ticker
 
 void rxCallback(MODSERIAL_IRQ_INFO *q) {
     if (um6_uart.rxBufferGetCount() >=  MAX_PACKET_DATA) {
@@ -22,7 +29,13 @@
         Process_um6_packet();
     }
 }
- 
+
+int doRead = 0;
+
+void print_um6() {
+    doRead = 1;    // interupt to read signals from UM6
+        
+}      
 
 int main() {
 
@@ -31,27 +44,47 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////
 
     // set UM6 serial uart baud 9600
-    um6_uart.baud(9600);
-    pc.baud(9600);  // pc baud for UM6 to pc interface
-
+    um6_uart.baud(115200);
+    pc.baud(115200);  // pc baud for UM6 to pc interface
+    t.start(); // starts timer
+    
     // attach interupt function to uart
     um6_uart.attach(&rxCallback, MODSERIAL::RxIrq);
 
-    int Roll_Counter = 0;
+    tick.attach(&print_um6, 0.50);
+
+    FILE *fp = fopen("/local/out3.csv", "w");  // Open "out.txt" on the local file system for writing
+    fprintf(fp, "time1 (s),Yaw (deg),Roll (deg),Pitch (deg),GyroX,GyroY,GyroZ,AccelX,AccelY,AccelZ,MagX,MagY,MagZ \r");   // sends header to file
 
-    while (1) {
-         Roll_Counter++;      
-         if (Roll_Counter > 5000000) {
-          pc.printf("Gyro_Proc_X %f deg/s, ",data.Gyro_Proc_X);
-          pc.printf("Gyro_Proc_Y %f deg/s, ",data.Gyro_Proc_Y);
-          pc.printf("Gyro_Proc_Z %f deg/s, ",data.Gyro_Proc_Z);
-          pc.printf("Roll %f deg, ",data.Roll);
-          pc.printf("Pitch %f deg, ",data.Pitch);
-          pc.printf("Yaw %f deg \r\n",data.Yaw);
-          pc_activity = !pc_activity;  // Lights LED when uart RxBuff has > 40 bytes
-          Roll_Counter = 0;
+    while (enable) {
+         logLED = 1; // turns LED3 on when logging starts                
+         if (doRead) { 
+           float time1=t.read();
+           float Yaw=data.Yaw;
+           float Roll=data.Roll;
+           float Pitch=data.Pitch;
+           float GyroX=data.Gyro_Proc_X;
+           float GyroY=data.Gyro_Proc_Y;
+           float GyroZ=data.Gyro_Proc_Z;
+           float AccelX=data.Accel_Proc_X;
+           float AccelY=data.Accel_Proc_Y;
+           float AccelZ=data.Accel_Proc_Z;
+           float MagX=data.Mag_Proc_X;
+           float MagY=data.Mag_Proc_Y;
+           float MagZ=data.Mag_Proc_Z;
+           float GPSlong=data.GPS_long;
+           
+           pc.printf("time1 %3.3f s,Yaw %3.3f deg,Roll %3.3f deg,Pitch %3.3f deg\n",time1,Yaw,Roll,Pitch);  
+           //pc.printf("time1 %3.3f s,Yaw %3.3f deg,Roll %3.3f deg,Pitch %3.3f deg, Longitude %f deg\n",time1,Yaw,Roll,Pitch,GPSlong);  
+           fprintf(fp, "%3.3f,%3.3f,%3.3f,%3.3f\n",time1,Yaw,Roll,Pitch);
+           //%3.3f,%3.3f,%3.3f,%3.3f,%3.3f,%3.3f,%3.3f,%3.3f,%3.3f\n",time1,Yaw,Roll,Pitch,GyroX,GyroY,GyroZ,AccelX,AccelY,AccelZ,MagX,MagY,MagZ);
+           
+           pc_activity = !pc_activity;  // Lights LED1 when uart RxBuff has > 40 bytes
+           doRead = 0; 
          }
-  
+      
     }  // end while(1) loop
+   logLED = 0;  // turns LED3 off when logging ends
+   fclose(fp);
 
 }  // end main()
\ No newline at end of file